unit Main;

interface

uses Windows, SysUtils, Classes, Graphics, Forms, Controls, Menus,
  StdCtrls, Dialogs, Buttons, Messages, ExtCtrls, ComCtrls, DBTables,
  DBOneF,inifiles,db;

type
  TMainForm = class(TForm)
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    FileNewItem: TMenuItem;
    FileOpenItem: TMenuItem;
    FileCloseItem: TMenuItem;
    Window1: TMenuItem;
    Help1: TMenuItem;
    N1: TMenuItem;
    FileExitItem: TMenuItem;
    WindowCascadeItem: TMenuItem;
    WindowTileItem: TMenuItem;
    WindowArrangeItem: TMenuItem;
    HelpAboutItem: TMenuItem;
    OpenDialog: TOpenDialog;
    FileSaveItem: TMenuItem;
    FileSaveAsItem: TMenuItem;
    WindowMinimizeItem: TMenuItem;
    SpeedPanel: TPanel;
    OpenBtn: TSpeedButton;
    SaveBtn: TSpeedButton;
    ExitBtn: TSpeedButton;
    StatusBar: TStatusBar;
    DBOneFile: TDBOneFile;
    SaveDialog: TSaveDialog;
    procedure FormCreate(Sender: TObject);
    procedure FileNewItemClick(Sender: TObject);
    procedure WindowCascadeItemClick(Sender: TObject);
    procedure UpdateMenuItems(Sender: TObject);
    procedure WindowTileItemClick(Sender: TObject);
    procedure WindowArrangeItemClick(Sender: TObject);
    procedure FileCloseItemClick(Sender: TObject);
    procedure FileOpenItemClick(Sender: TObject);
    procedure FileExitItemClick(Sender: TObject);
    procedure FileSaveItemClick(Sender: TObject);
    procedure FileSaveAsItemClick(Sender: TObject);
    procedure CutItemClick(Sender: TObject);
    procedure CopyItemClick(Sender: TObject);
    procedure PasteItemClick(Sender: TObject);
    procedure WindowMinimizeItemClick(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure HelpAboutItemClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
  private
    { Private declarations }
    procedure CreateMDIChild(const Name: string);
    procedure ShowHint(Sender: TObject);
  public
    { Public declarations }
    Inifile:TInifile;
    FLDirBase:string;
    procedure WriteIniFile;
    procedure ReadIniFile;
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

uses ChildWin, About;


procedure TMainForm.WriteIniFile;
begin
  IniFile.WriteString('Directory', 'DirBase', FLDirBase);
end;

procedure TMainForm.ReadIniFile;
begin
  IniFile  := TIniFile.Create(ChangeFileExt(Application.ExeName, '.INI'));

  FLDirBase := IniFile.ReadString('Directory', 'DirBase', ExtractFilePath(Application.ExeName));
end;

procedure TMainForm.FormCreate(Sender: TObject);
begin
  Application.OnHint := ShowHint;
  Screen.OnActiveFormChange := UpdateMenuItems;
end;

procedure TMainForm.ShowHint(Sender: TObject);
begin
  StatusBar.SimpleText := Application.Hint;
end;

procedure TMainForm.CreateMDIChild(const Name: string);
var
  Child: TMDIChild;
begin
  { create a new MDI child window }
  Child := TMDIChild.Create(Application);
  Child.Caption := Name;
end;

procedure TMainForm.FileNewItemClick(Sender: TObject);
var
  Child: TMDIChild;
begin
  { create a new MDI child window }
  Child := TMDIChild.Create(Application);
  with Child do
       begin
       DBfile:=DBOneFile.NewDB;
       DBDir:=DBOneFile.Directory(Child.DBfile);

       Caption := Child.DBFile;
       LabelDir.Caption:=Child.DBDir;
       LabelFile.Caption:=Child.DBfile;

       {init of tables}
       Table1.DatabaseName:=DBDir;
       Table1.Active:=True;
       Table2.DatabaseName:=DBDir;
       Table2.Active:=True;
       end;

end;

procedure TMainForm.FileOpenItemClick(Sender: TObject);
var
  Child: TMDIChild;
begin
  { open an existing file createdet with  DBOneFile}
  if OpenDialog.Execute then
     begin
     Child := TMDIChild.Create(Application);
     with Child do
          begin
          DBOneFile.Open(OpenDialog.Filename);
          DBfile:=OpenDialog.Filename;
          DBDir:=DBOneFile.Directory(Child.DBfile);

          Caption := Child.DBFile;
          LabelDir.Caption:=Child.DBDir;
          LabelFile.Caption:=Child.DBfile;

          {init of tables}
          Table1.DatabaseName:=DBDir;
          Table1.Active:=True;
          Table2.DatabaseName:=DBDir;
          Table2.Active:=True;
        end;
     end;
end;

procedure TMainForm.FileCloseItemClick(Sender: TObject);
begin
  if ActiveMDIChild <> nil then
    ActiveMDIChild.Close;
end;

procedure TMainForm.FileSaveItemClick(Sender: TObject);
begin
  { save current file (ActiveMDIChild points to the window) }
  with TMDIChild(ActiveMDIChild) do
       begin
       if Table1.State<>dsBrowse then
          Table1.Post;
       if Table2.State<>dsBrowse then
          Table2.Post;
       Table1.Active:=False;
       Table2.Active:=False;

       DBOneFile.Save(DBFile);

       Table1.Active:=True;
       Table2.Active:=True;
       end;
end;

procedure TMainForm.FileSaveAsItemClick(Sender: TObject);
begin
  { save current file under new name }
  if SaveDialog.Execute then
  with TMDIChild(ActiveMDIChild) do
       begin
       if Table1.State<>dsBrowse then
          Table1.Post;
       if Table2.State<>dsBrowse then
          Table2.Post;
       Table1.Active:=False;
       Table2.Active:=False;
       DBOneFile.SaveAS(DBFile,SaveDialog.Filename);
       Table1.Active:=True;
       Table2.Active:=True;
       
       LabelFile.Caption:=SaveDialog.Filename;
       Caption:=SaveDialog.Filename;
       end;

end;

procedure TMainForm.FileExitItemClick(Sender: TObject);
begin
  Close;
end;

procedure TMainForm.CutItemClick(Sender: TObject);
begin
  {cut selection to clipboard}
end;

procedure TMainForm.CopyItemClick(Sender: TObject);
begin
  {copy selection to clipboard}
end;

procedure TMainForm.PasteItemClick(Sender: TObject);
begin
  {paste from clipboard}
end;

procedure TMainForm.WindowCascadeItemClick(Sender: TObject);
begin
  Cascade;
end;

procedure TMainForm.WindowTileItemClick(Sender: TObject);
begin
  Tile;
end;

procedure TMainForm.WindowArrangeItemClick(Sender: TObject);
begin
  ArrangeIcons;
end;

procedure TMainForm.WindowMinimizeItemClick(Sender: TObject);
var
  I: Integer;
begin
  { Must be done backwards through the MDIChildren array }
  for I := MDIChildCount - 1 downto 0 do
    MDIChildren[I].WindowState := wsMinimized;
end;

procedure TMainForm.UpdateMenuItems(Sender: TObject);
begin
  FileCloseItem.Enabled := MDIChildCount > 0;
  FileSaveItem.Enabled := MDIChildCount > 0;
  FileSaveAsItem.Enabled := MDIChildCount > 0;
  SaveBtn.Enabled := MDIChildCount > 0;
  WindowCascadeItem.Enabled := MDIChildCount > 0;
  WindowTileItem.Enabled := MDIChildCount > 0;
  WindowArrangeItem.Enabled := MDIChildCount > 0;
  WindowMinimizeItem.Enabled := MDIChildCount > 0;
end;

procedure TMainForm.FormDestroy(Sender: TObject);
begin
  Screen.OnActiveFormChange := nil;
  WriteIniFile;
end;

procedure TMainForm.HelpAboutItemClick(Sender: TObject);
begin
  AboutBox.ShowModal;
end;

procedure TMainForm.FormShow(Sender: TObject);
begin
ReadIniFile;

DBOneFile.DBDefaultDir:=FLDirBase;
DBOneFile.DBEmptyFile:=FLDirBase+'emptydb.edb';
if FLDirBase[Length(FLDirBase)]='\' then
   DBOneFile.TempWorkDir:=Copy(FLDirBase,1,length(FLDirBase)-1)
else
   DBOneFile.TempWorkDir:=FLDirBase;

SaveDialog.InitialDir:=FLDirBase;
OpenDialog.InitialDir:=FLDirBase;
end;

end.
